@@ -110,10 +110,16 @@ class sentence_tranformer():
             for i in (np.where(cosine_results == x)[1]):
                 match_idxs.append(i)
                 targets.append(self.target_names[i])
-                max_cosines.append(x)
+                max_cosines.append(float(x))
                 if len(targets) == self.topn:
                     break
-
+                # fill empty topn results 
+                
+        while len(targets) < self.topn:
+            match_idxs.append(None)
+            targets.append(None)
+            max_cosines.append(None)
+            
         return targets, max_cosines, match_idxs
     
 
@@ -130,11 +136,10 @@ class sentence_tranformer():
             for source, targets, top_scores in zip(self.source_names, self.targets, self.top_cosine):
                 row = []
                 row.append(source)
-                if targets is not None:
-                    # loop over results of multi matches
-                    for target, top_score in zip(targets, top_scores):
-                        row.append(target)
-                        row.append(top_score) 
+                # loop over results of multi matches
+                for target, top_score in zip(targets, top_scores):
+                    row.append(target)
+                    row.append(top_score) 
                 match_list.append(tuple(row))
 
             # prepare columns names
@@ -150,12 +155,11 @@ class sentence_tranformer():
             for source, targets, top_scores, match_idxs in zip(self.source_names, self.targets, self.top_cosine, self.match_idxs):
                 row = []
                 row.append(source)
-                if targets is not None:
-                    # loop over results of multi matches
-                    for target, top_score, match_idx in zip(targets, top_scores, match_idxs):
-                        row.append(target)
-                        row.append(top_score) 
-                        row.append(match_idx)
+                # loop over results of multi matches
+                for target, top_score, match_idx in zip(targets, top_scores, match_idxs):
+                    row.append(target)
+                    row.append(top_score) 
+                    row.append(match_idx)
                 match_list.append(tuple(row))
 
             # prepare columns names
